/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */
package com.yifu.cloud.plus.v1.yifu.social.vo;

import com.alibaba.excel.annotation.ExcelProperty;
import com.alibaba.excel.annotation.write.style.HeadFontStyle;
import com.yifu.cloud.plus.v1.yifu.common.core.constant.ExcelAttribute;
import com.yifu.cloud.plus.v1.yifu.common.core.vo.RowIndex;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * 缴费库查询导出字段
 * @author huyc
 * @date 2023-05-18 17:01:22
 */
@Data
public class TPaymentInfoNewExportVo extends RowIndex implements Serializable {

	/**
	 * 员工姓名
	 */
	@ExcelAttribute(name = "员工姓名" )
	@Schema(description ="员工姓名")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("员工姓名")
	private String empName;

	/**
	 * 身份证号
	 */
	@ExcelAttribute(name = "身份证号" )
	@Schema(description ="身份证号")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("身份证号")
	private String empIdcard;

	/**
	 * 客户名称
	 */
	@ExcelAttribute(name = "客户名称" )
	@Schema(description ="客户名称")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("客户名称")
	private String unitName;

	/**
	 * 项目名称
	 */
	@ExcelAttribute(name = "项目名称" )
	@Schema(description ="项目名称")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("项目名称")
	private String settleDomainName;

	/**
	 * 社保缴纳地
	 */
	@ExcelAttribute(name = "社保缴纳地" )
	@Schema(description ="社保缴纳地")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("社保缴纳地")
	private String socialPayAddr;

	/**
	 * 缴纳月份
	 */
	@ExcelAttribute(name = "缴纳月份")
	@Schema(description ="缴纳月份")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("缴纳月份")
	private String socialPayMonth;

	/**
	 * 生成月份
	 */
	@ExcelAttribute(name = "生成月份")
	@Schema(description ="生成月份")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("生成月份")
	private String socialCreateMonth;

	/**
	 * 养老金额
	 */
	@ExcelAttribute(name = "养老金额")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("养老金额")
	private BigDecimal pensionMoneySum;
	/**
	 * 医疗金额
	 */
	@ExcelAttribute(name = "医疗金额")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("医疗金额")
	private BigDecimal medicalMoneySum;
	/**
	 * 失业金额
	 */
	@ExcelAttribute(name = "失业金额")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("失业金额")
	private BigDecimal unemploymentMoneySum;
	/**
	 * 工伤金额
	 */
	@ExcelAttribute(name = "工伤金额")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("工伤金额")
	private BigDecimal unitInjuryMoney;
	/**
	 * 单位生育金额
	 */
	@ExcelAttribute(name = "生育金额")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("生育金额")
	private BigDecimal unitBirthMoney;
	/**
	 * 大病金额
	 */
	@ExcelAttribute(name = "大病金额")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("大病金额")
	private BigDecimal bigmailmentMoneySum;
	/**
	 * 补缴利息
	 */
	@ExcelAttribute(name = "补缴利息"  )
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("补缴利息")
	private BigDecimal accrualSum;

	/**
	 * 社保户
	 */
	@ExcelAttribute(name = "社保户" )
	@Schema(description ="社保户")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("社保户")
	private String socialHousehold;

	/**
	 * 社保合计
	 */
	@ExcelAttribute(name = "社保合计" )
	@Schema(description ="社保合计")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("社保合计")
	private BigDecimal socialSum;

	/**
	 * 公积金户
	 */
	@ExcelAttribute(name = "公积金户" )
	@Schema(description ="公积金户")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金户")
	private String providentHousehold;

	/**
	 * 公积金缴纳地
	 */
	@ExcelAttribute(name = "公积金缴纳地" )
	@Schema(description ="公积金缴纳地")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金缴纳地")
	private String providentPayAddr;

	/**
	 * 公积金合计
	 */
	@ExcelAttribute(name = "公积金合计" )
	@Schema(description ="公积金合计")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("公积金合计")
	private BigDecimal providentSum;

	/**
	 * 总合计
	 */
	@ExcelAttribute(name = "总合计" )
	@Schema(description ="总合计")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("总合计")
	private BigDecimal sumAll;

	/**
	 * 分组键
	 */
	@ExcelAttribute(name = "分组键", isExport = false)
	@Schema(description = "分组键")
	private String keyGroup;

}
